@@ -1225,7 +1225,6 @@ class Booltest(object):
             jscres['offset'] = coffset
 
             tvsize = self.adjust_tvsize(tvsize, size, coffset)
-            logger.warning("FUCK")
             self.hwanalysis = self.setup_hwanalysis(self.deg, self.top_comb, self.top_k, self.all_deg, zscore_thresh)
             if self.hwanalysis.ref_db_path:
                 logger.info('Using reference data file %s' % self.hwanalysis.ref_db_path)
@@ -1488,7 +1487,7 @@ class Booltest(object):
                             help='Probability the given combination is going to be chosen. '
                                  'Enables stochastic test, useful for large degrees.')
 
-        parser.add_argument('--default-params', dest='default_params', action='store_const', const=True, default=False,
+        parser.add_argument('--default-params', dest='default_params', type=int, default=1,
                             help='Default parameter settings for testing, used in the paper')
 
         parser.add_argument('files', nargs=argparse.ZERO_OR_MORE, default=[],
